hisma_console_monitor library

Simple monitor implementation for the Hisma package.

Hisma defines a monitoring API: One can register monitor creator functions and the monitors created by these will be invoked by Hisma when the state machines are created or their active state changes. This monitor is a simple monitor implementation for Hisma. It logs these events formatted to the console.

Classes

ConsoleMonitor
When configured for Machine it reports (by default to the console) creation and state changes of this machine included with all its compounded state machines.

Functions

pretty(List activeState, {String tab = '', bool last = true}) String
Convert Machine active state representation to a human readable string. An uml state machine can be a hierarchy of state machine due to implementing compound state regions with child state machines, the active state of the machine is not represented by a single state identifier but a hierarchic array of active state. Example: