ConsoleMonitor class

When configured for Machine it reports (by default to the console) creation and state changes of this machine included with all its compounded state machines.

Constructors

ConsoleMonitor(Machine stateMachine, {void printer(String) = _simplePrint, bool includeInactive = true})
The stateMachine is the state machine to be monitored. printer defines a function we want monitor to use to output machine structure. If not given the default implementation will use stdout.write. When includeInactive is false only the active machines and their active state will be present in the output.

Properties

hashCode int
The hash code for this object.
no setterinherited
includeInactive bool
final
printer → void Function(String)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateMachine → Machine
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyCreation() Future<void>
notifyStateChange() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited