ConsoleMonitor constructor

ConsoleMonitor(
  1. Machine stateMachine, {
  2. void printer(
    1. String
    ) = _simplePrint,
  3. bool includeInactive = true,
})

The stateMachine is the state machine to be monitored. printer defines a function we want monitor to use to output machine structure. If not given the default implementation will use stdout.write. When includeInactive is false only the active machines and their active state will be present in the output.

Implementation

ConsoleMonitor(
  this.stateMachine, {
  this.printer = _simplePrint,
  this.includeInactive = true,
});